==> aws_prototyping_sdk.cloudscape_react_ts_website-0.4.0.tar.gz: package/lib/cloudscape-react-ts-website-project.d.ts <==
/*********************************************************************************************************************
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

 Licensed under the Apache License, Version 2.0 (the "License").
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 ******************************************************************************************************************** */
import { ReactTypeScriptProject, ReactTypeScriptProjectOptions } from "projen/lib/web";
/**
 * Configuration options for the CloudscapeReactTsWebsiteProject.
 */
export interface CloudscapeReactTsWebsiteProjectOptions extends ReactTypeScriptProjectOptions {
    /**
     * Name of the application name.
     *
     * @default "Sample App"
     */
    readonly applicationName?: string;
    /**
     * Public directory.
     *
     * @default "public"
     */
    readonly publicDir?: string;
}
/**
 * Synthesizes a Cloudscape React Typescript Website Project.
 *
 * @pjid Cloudscape-react-ts-website
 */
export declare class CloudscapeReactTsWebsiteProject extends ReactTypeScriptProject {
    readonly applicationName: string;
    readonly publicDir: string;
    constructor(options: CloudscapeReactTsWebsiteProjectOptions);
}

==> aws_prototyping_sdk.cloudscape_react_ts_website-0.7.1.tar.gz: package/lib/cloudscape-react-ts-website-project.d.ts <==
/*********************************************************************************************************************
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

 Licensed under the Apache License, Version 2.0 (the "License").
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 ******************************************************************************************************************** */
import { ReactTypeScriptProject, ReactTypeScriptProjectOptions } from "projen/lib/web";
/**
 * Configuration options for the CloudscapeReactTsWebsiteProject.
 */
export interface CloudscapeReactTsWebsiteProjectOptions extends ReactTypeScriptProjectOptions {
    /**
     * Name of the application name.
     *
     * @default "Sample App"
     */
    readonly applicationName?: string;
    /**
     * Public directory.
     *
     * @default "public"
     */
    readonly publicDir?: string;
}
/**
 * Synthesizes a Cloudscape React Typescript Website Project.
 *
 * @pjid cloudscape-react-ts-website
 */
export declare class CloudscapeReactTsWebsiteProject extends ReactTypeScriptProject {
    readonly applicationName: string;
    readonly publicDir: string;
    constructor(options: CloudscapeReactTsWebsiteProjectOptions);
}
